Python: module booman.frame

booman.frame | index booman/frame.py

`# Boodler: a programmable soundscape tool
# Copyright 2007-9 by Andrew Plotkin <erkyrath@eblong.com>
# <http://boodler.org/>
# This program is distributed under the LGPL.
# See the LGPL document, or the above URL, for details.`

Modules
`` |  |
StringIO booman | boopak.collect booman.token | traceback |

Functions
`` |  | cleanup() `cleanup() -> None Shut down the PackageCollection object. Must be called when the interpreter is exiting.` get_last_backtrace() `get_last_backtrace() -> str Get a string representation of the backtrace of the last Exception that was caught. (The return string will have several lines, separated by newlines. However, it will not end with a newline.)` handle(args=None) `handle(args=None) -> None Process one command (from user input, or from the arguments provided). In interactive mode, this is called repeatedly. If there are command- line arguments, this is called once, with the list of arguments passed in. This catches all exceptions except KeyboardInterrupt.` note_backtrace() `note_backtrace() -> None Record a string representation of the backtrace of the current Exception. This should only be called from an exception handler.` quit_yet() `quit_yet() -> bool Return whether the Quit command has been executed.` set_force_option(val=True) `set_force_option(val=True) -> None Set whether the interpreter should prompt to confirm dangerous actions. (True means don't.) This is called during setup if the --force option was supplied.` set_interactive(val=True) `set_interactive(val=True) -> None Set whether the interpreter is prompting for commands, or if commands were supplied as arguments.` set_quit(val=True) `set_quit(val=True) -> None Set the shutdown flag. This is called when the Quit command is executed.` setup_loader(basedir, coldir, dldir, importing_ok=False) `setup_loader(basedir, coldir, dldir, importing_ok=False) -> None Create the PackageCollection, which will be used by all commands. (See the PackageCollection class for the arguments.)`

Data
`` |  | is_force = False is_interactive = False last_backtrace = None loader = None shutdown = False